@@ -1,7 +1,7 @@
 ##' @importFrom R6 R6Class
 cache <- new.env(parent = emptyenv())
 
-.onLoad <- function(...) {
+.onLoad <- function(...) { # nolint
   migrations <- package_version(names(available_migrations()))
   cache$current_archive_version <-
     utils::tail(migrations[migrations <= utils::packageVersion("orderly")], 1L)
