@@ -2,7 +2,7 @@ context("readme")
 
 test_that("auto copy README.md",  {
   skip_on_cran_windows()
-  path <- prepare_orderly_example("minimal")
+  path <- test_prepare_orderly_example("minimal")
   ## in report directory create a file called README.md
   report_path <- file.path(path, "src", "example")
   file.create(file.path(report_path, "README.md"))
@@ -18,23 +18,23 @@ test_that("auto copy README.md",  {
 
 test_that("lowercase README.md",  {
   skip_on_cran_windows()
-  path <- prepare_orderly_example("minimal")
+  path <- test_prepare_orderly_example("minimal")
   ## in report directory create a file called README.md
   report_path <- file.path(path, "src", "example")
   file.create(file.path(report_path, "readme.MD"))
   id <- orderly_run("example", root = path, echo = FALSE)
   p <- file.path(path, "draft", "example", id)
-  expect_true(file.exists(file.path(p, "README.MD")))
+  expect_true(file.exists(file.path(p, "README.md")))
   orderly_commit(id, root = path)
   con <- orderly_db("destination", root = path)
   on.exit(DBI::dbDisconnect(con))
   dat <- DBI::dbReadTable(con, "file_input")
-  expect_equal(sum(dat$filename == "README.MD"), 1)
+  expect_equal(sum(dat$filename == "README.md"), 1)
 })
 
 test_that("list README.md as resource",  {
   skip_on_cran_windows()
-  path <- prepare_orderly_example("minimal")
+  path <- test_prepare_orderly_example("minimal")
   report_path <- file.path(path, "src", "example")
   ## in report directory create a file called README.md
   path_example <- file.path(path, "src", "example")
@@ -61,7 +61,7 @@ test_that("list README.md as resource",  {
 
 test_that("list README.md as artefact",  {
   skip_on_cran_windows()
-  path <- prepare_orderly_example("minimal")
+  path <- test_prepare_orderly_example("minimal")
   report_path <- file.path(path, "src", "example")
   ## in report directory create a file called README.md
   path_example <- file.path(path, "src", "example")
@@ -89,7 +89,7 @@ test_that("list README.md as artefact",  {
 
 test_that("readme db",  {
   skip_on_cran_windows()
-  path <- prepare_orderly_example("minimal")
+  path <- test_prepare_orderly_example("minimal")
   report_path <- file.path(path, "src", "example")
   file.create(file.path(report_path, "README.md"))
   id <- orderly_run("example", root = path, echo = FALSE)
@@ -110,7 +110,7 @@ test_that("readme db",  {
 
 test_that("copy readme in sub-directory", {
   skip_on_cran_windows()
-  path <- prepare_orderly_example("demo")
+  path <- test_prepare_orderly_example("demo")
   ## in report directory create a file called README.md
   report_path <- file.path(path, "src", "use_resource")
 
@@ -132,7 +132,7 @@ test_that("copy readme in sub-directory", {
 
 test_that("list README.md as resource in sub-directory", {
   skip_on_cran_windows()
-  path <- prepare_orderly_example("demo")
+  path <- test_prepare_orderly_example("demo")
   ## in report directory create a file called README.md
   report_path <- file.path(path, "src", "use_resource")
   # add a readme fiel to the meta data directory
@@ -155,16 +155,23 @@ test_that("list README.md as resource in sub-directory", {
            "requester: ACME"
            )
   writeLines(yml, file.path(yml_path))
+
   # make sure we get a warning about this
   messages <- capture_messages(
     id <- orderly_run("use_resource", root = path, echo = FALSE))
-  expect_true(any(grep("should not be listed as a resource", messages)))
+  expect_match(
+    messages, "'meta/README.md' should not be listed as a resource",
+    fixed = TRUE, all = FALSE)
+  expect_match(
+    messages, "'README.md' should not be listed as a resource",
+    fixed = TRUE, all = FALSE)
 
   ## Try again _without_ listing the READMEs as a resource so that we
   ## see that they're copied over
   writeLines(yml[!grepl("README", yml)], file.path(yml_path))
-  id <- orderly_run("use_resource", root = path, echo = FALSE)
-
+  messages <- capture_messages(
+    id <- orderly_run("use_resource", root = path, echo = FALSE))
+  expect_false(any(grepl("should not be listed as a resource", messages)))
   p <- file.path(path, "draft", "use_resource", id)
   # make sure the file has been copied across
   expect_true(file.exists(file.path(p, "meta", "README.md")))
